diff --git a/doc/src/sgml/monitoring.sgml b/doc/src/sgml/monitoring.sgml
index 6656676..1326e51 100644
--- a/doc/src/sgml/monitoring.sgml
+++ b/doc/src/sgml/monitoring.sgml
@@ -2590,7 +2590,7 @@ SELECT pid, wait_event_type, wait_event FROM pg_stat_activity WHERE wait_event i
     <tbody>
      <row>
       <entry role="catalog_table_entry"><para role="column_definition">
-        <structfield>name</structfield> <type>text</type>
+        <structfield>slot_name</structfield> <type>name</type>
        </para>
        <para>
         A unique, cluster-wide identifier for the replication slot
diff --git a/src/backend/catalog/system_views.sql b/src/backend/catalog/system_views.sql
index c293907..0ea3d19 100644
--- a/src/backend/catalog/system_views.sql
+++ b/src/backend/catalog/system_views.sql
@@ -798,7 +798,7 @@ CREATE VIEW pg_stat_replication AS
 
 CREATE VIEW pg_stat_replication_slots AS
     SELECT
-            s.name,
+            s.name AS slot_name,
             s.spill_txns,
             s.spill_count,
             s.spill_bytes,
diff --git a/src/backend/postmaster/pgstat.c b/src/backend/postmaster/pgstat.c
index 822f0eb..81156f7 100644
--- a/src/backend/postmaster/pgstat.c
+++ b/src/backend/postmaster/pgstat.c
@@ -7094,7 +7094,7 @@ pgstat_replslot_index(const char *name, bool create_it)
 	Assert(nReplSlotStats <= max_replication_slots);
 	for (i = 0; i < nReplSlotStats; i++)
 	{
-		if (strcmp(replSlotStats[i].slotname, name) == 0)
+		if (strcmp(replSlotStats[i].slotname.data, name) == 0)
 			return i;			/* found */
 	}
 
@@ -7107,7 +7107,7 @@ pgstat_replslot_index(const char *name, bool create_it)
 
 	/* Register new slot */
 	memset(&replSlotStats[nReplSlotStats], 0, sizeof(PgStat_ReplSlotStats));
-	memcpy(&replSlotStats[nReplSlotStats].slotname, name, NAMEDATALEN);
+	memcpy(&replSlotStats[nReplSlotStats].slotname.data, name, NAMEDATALEN);
 
 	return nReplSlotStats++;
 }
diff --git a/src/backend/utils/adt/pgstatfuncs.c b/src/backend/utils/adt/pgstatfuncs.c
index 0d0d2e6..57b1226 100644
--- a/src/backend/utils/adt/pgstatfuncs.c
+++ b/src/backend/utils/adt/pgstatfuncs.c
@@ -2153,7 +2153,7 @@ pg_stat_get_archiver(PG_FUNCTION_ARGS)
 Datum
 pg_stat_get_replication_slots(PG_FUNCTION_ARGS)
 {
-#define PG_STAT_GET_REPLICATION_SLOT_CLOS 5
+#define PG_STAT_GET_REPLICATION_SLOT_COLS 5
 	ReturnSetInfo *rsinfo = (ReturnSetInfo *) fcinfo->resultinfo;
 	TupleDesc	tupdesc;
 	Tuplestorestate *tupstore;
@@ -2190,14 +2190,14 @@ pg_stat_get_replication_slots(PG_FUNCTION_ARGS)
 	slotstats = pgstat_fetch_replslot(&nstats);
 	for (i = 0; i < nstats; i++)
 	{
-		Datum		values[PG_STAT_GET_REPLICATION_SLOT_CLOS];
-		bool		nulls[PG_STAT_GET_REPLICATION_SLOT_CLOS];
+		Datum		values[PG_STAT_GET_REPLICATION_SLOT_COLS];
+		bool		nulls[PG_STAT_GET_REPLICATION_SLOT_COLS];
 		PgStat_ReplSlotStats *s = &(slotstats[i]);
 
 		MemSet(values, 0, sizeof(values));
 		MemSet(nulls, 0, sizeof(nulls));
 
-		values[0] = PointerGetDatum(cstring_to_text(s->slotname));
+		values[0] = NameGetDatum(&s->slotname);
 		values[1] = Int64GetDatum(s->spill_txns);
 		values[2] = Int64GetDatum(s->spill_count);
 		values[3] = Int64GetDatum(s->spill_bytes);
diff --git a/src/include/catalog/pg_proc.dat b/src/include/catalog/pg_proc.dat
index 22340ba..5685824 100644
--- a/src/include/catalog/pg_proc.dat
+++ b/src/include/catalog/pg_proc.dat
@@ -5261,7 +5261,7 @@
   proname => 'pg_stat_get_replication_slots', prorows => '10', proisstrict => 'f',
   proretset => 't', provolatile => 's', proparallel => 'r',
   prorettype => 'record', proargtypes => '',
-  proallargtypes => '{text,int8,int8,int8,timestamptz}',
+  proallargtypes => '{name,int8,int8,int8,timestamptz}',
   proargmodes => '{o,o,o,o,o}',
   proargnames => '{name,spill_txns,spill_count,spill_bytes,stats_reset}',
   prosrc => 'pg_stat_get_replication_slots' },
diff --git a/src/include/pgstat.h b/src/include/pgstat.h
index a821ff4..eccbb8c 100644
--- a/src/include/pgstat.h
+++ b/src/include/pgstat.h
@@ -819,7 +819,7 @@ typedef struct PgStat_SLRUStats
  */
 typedef struct PgStat_ReplSlotStats
 {
-	char		slotname[NAMEDATALEN];
+	NameData	slotname;
 	PgStat_Counter spill_txns;
 	PgStat_Counter spill_count;
 	PgStat_Counter spill_bytes;
